.. rst-class:: detail

SetAnalog
====================

.. currentmodule:: compas_rrc

.. autoclass:: SetAnalog

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~SetAnalog.__init__
        ~SetAnalog.from_msg
    
    